==> openshift-model-miscellaneous-5.10.1-sources.jar: io/fabric8/openshift/api/model/miscellaneous/cloudcredential/v1/CredentialsRequestSpecFluentImpl.java <==
package io.fabric8.openshift.api.model.miscellaneous.cloudcredential.v1;

import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import io.fabric8.kubernetes.api.model.ObjectReferenceFluentImpl;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import io.fabric8.kubernetes.api.model.ObjectReference;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.model.ObjectReferenceBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class CredentialsRequestSpecFluentImpl<A extends io.fabric8.openshift.api.model.miscellaneous.cloudcredential.v1.CredentialsRequestSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.miscellaneous.cloudcredential.v1.CredentialsRequestSpecFluent<A>{
  public CredentialsRequestSpecFluentImpl() {
  }
  public CredentialsRequestSpecFluentImpl(io.fabric8.openshift.api.model.miscellaneous.cloudcredential.v1.CredentialsRequestSpec instance) {
    this.withProviderSpec(instance.getProviderSpec()); 
    this.withSecretRef(instance.getSecretRef()); 
    this.withServiceAccountNames(instance.getServiceAccountNames()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.util.Map<java.lang.String,java.lang.Object> providerSpec;
  private io.fabric8.kubernetes.api.model.ObjectReferenceBuilder secretRef;
  private java.util.List<java.lang.String> serviceAccountNames = new java.util.ArrayList<java.lang.String>();
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public A addToProviderSpec(java.lang.String key,java.lang.Object value) {
    if(this.providerSpec == null && key != null && value != null) { this.providerSpec = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.providerSpec.put(key, value);} return (A)this;
  }
  public A addToProviderSpec(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.providerSpec == null && map != null) { this.providerSpec = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.providerSpec.putAll(map);} return (A)this;
  }
  public A removeFromProviderSpec(java.lang.String key) {
    if(this.providerSpec == null) { return (A) this; }
    if(key != null && this.providerSpec != null) {this.providerSpec.remove(key);} return (A)this;
  }
  public A removeFromProviderSpec(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.providerSpec == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.providerSpec != null){this.providerSpec.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getProviderSpec() {
    return this.providerSpec;
  }
  public <K,V>A withProviderSpec(java.util.Map<java.lang.String,java.lang.Object> providerSpec) {
    if (providerSpec == null) { this.providerSpec =  null;} else {this.providerSpec = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(providerSpec);} return (A) this;
  }
  public java.lang.Boolean hasProviderSpec() {
    return this.providerSpec != null;
  }
  
  /**
   * This method has been deprecated, please use method buildSecretRef instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.ObjectReference getSecretRef() {
    return this.secretRef!=null?this.secretRef.build():null;
  }
  public io.fabric8.kubernetes.api.model.ObjectReference buildSecretRef() {
    return this.secretRef!=null?this.secretRef.build():null;
  }
  public A withSecretRef(io.fabric8.kubernetes.api.model.ObjectReference secretRef) {
    _visitables.get("secretRef").remove(this.secretRef);
    if (secretRef!=null){ this.secretRef= new io.fabric8.kubernetes.api.model.ObjectReferenceBuilder(secretRef); _visitables.get("secretRef").add(this.secretRef);} return (A) this;
  }
  public java.lang.Boolean hasSecretRef() {
    return this.secretRef != null;
  }
  public io.fabric8.openshift.api.model.miscellaneous.cloudcredential.v1.CredentialsRequestSpecFluent.SecretRefNested<A> withNewSecretRef() {
    return new io.fabric8.openshift.api.model.miscellaneous.cloudcredential.v1.CredentialsRequestSpecFluentImpl.SecretRefNestedImpl();
  }
  public io.fabric8.openshift.api.model.miscellaneous.cloudcredential.v1.CredentialsRequestSpecFluent.SecretRefNested<A> withNewSecretRefLike(io.fabric8.kubernetes.api.model.ObjectReference item) {
    return new io.fabric8.openshift.api.model.miscellaneous.cloudcredential.v1.CredentialsRequestSpecFluentImpl.SecretRefNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.miscellaneous.cloudcredential.v1.CredentialsRequestSpecFluent.SecretRefNested<A> editSecretRef() {
    return withNewSecretRefLike(getSecretRef());
  }
  public io.fabric8.openshift.api.model.miscellaneous.cloudcredential.v1.CredentialsRequestSpecFluent.SecretRefNested<A> editOrNewSecretRef() {
    return withNewSecretRefLike(getSecretRef() != null ? getSecretRef(): new io.fabric8.kubernetes.api.model.ObjectReferenceBuilder().build());
  }
  public io.fabric8.openshift.api.model.miscellaneous.cloudcredential.v1.CredentialsRequestSpecFluent.SecretRefNested<A> editOrNewSecretRefLike(io.fabric8.kubernetes.api.model.ObjectReference item) {
    return withNewSecretRefLike(getSecretRef() != null ? getSecretRef(): item);
  }
  public A addToServiceAccountNames(java.lang.Integer index,java.lang.String item) {
    if (this.serviceAccountNames == null) {this.serviceAccountNames = new java.util.ArrayList<java.lang.String>();}
    this.serviceAccountNames.add(index, item);
    return (A)this;
  }
  public A setToServiceAccountNames(java.lang.Integer index,java.lang.String item) {
    if (this.serviceAccountNames == null) {this.serviceAccountNames = new java.util.ArrayList<java.lang.String>();}
    this.serviceAccountNames.set(index, item); return (A)this;
  }
  public A addToServiceAccountNames(java.lang.String... items) {
    if (this.serviceAccountNames == null) {this.serviceAccountNames = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.serviceAccountNames.add(item);} return (A)this;
  }
  public A addAllToServiceAccountNames(java.util.Collection<java.lang.String> items) {
    if (this.serviceAccountNames == null) {this.serviceAccountNames = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.serviceAccountNames.add(item);} return (A)this;
  }
  public A removeFromServiceAccountNames(java.lang.String... items) {
    for (java.lang.String item : items) {if (this.serviceAccountNames!= null){ this.serviceAccountNames.remove(item);}} return (A)this;
  }
  public A removeAllFromServiceAccountNames(java.util.Collection<java.lang.String> items) {
    for (java.lang.String item : items) {if (this.serviceAccountNames!= null){ this.serviceAccountNames.remove(item);}} return (A)this;
  }
  public java.util.List<java.lang.String> getServiceAccountNames() {
    return this.serviceAccountNames;
  }
  public java.lang.String getServiceAccountName(java.lang.Integer index) {
    return this.serviceAccountNames.get(index);
  }
  public java.lang.String getFirstServiceAccountName() {
    return this.serviceAccountNames.get(0);
  }
  public java.lang.String getLastServiceAccountName() {
    return this.serviceAccountNames.get(serviceAccountNames.size() - 1);
  }
  public java.lang.String getMatchingServiceAccountName(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: serviceAccountNames) { if(predicate.test(item)){ return item;} } return null;
  }
  public java.lang.Boolean hasMatchingServiceAccountName(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: serviceAccountNames) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withServiceAccountNames(java.util.List<java.lang.String> serviceAccountNames) {
    if (serviceAccountNames != null) {this.serviceAccountNames = new java.util.ArrayList<java.lang.String>(); for (java.lang.String item : serviceAccountNames){this.addToServiceAccountNames(item);}} else { this.serviceAccountNames = null;} return (A) this;
  }
  public A withServiceAccountNames(java.lang.String... serviceAccountNames) {
    if (this.serviceAccountNames != null) {this.serviceAccountNames.clear();}
    if (serviceAccountNames != null) {for (java.lang.String item :serviceAccountNames){ this.addToServiceAccountNames(item);}} return (A) this;
  }
  public java.lang.Boolean hasServiceAccountNames() {
    return serviceAccountNames != null && !serviceAccountNames.isEmpty();
  }
  public A addNewServiceAccountName(java.lang.String arg0) {
    return (A)addToServiceAccountNames(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    CredentialsRequestSpecFluentImpl that = (CredentialsRequestSpecFluentImpl) o;
    if (providerSpec != null ? !providerSpec.equals(that.providerSpec) :that.providerSpec != null) return false;
    if (secretRef != null ? !secretRef.equals(that.secretRef) :that.secretRef != null) return false;
    if (serviceAccountNames != null ? !serviceAccountNames.equals(that.serviceAccountNames) :that.serviceAccountNames != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(providerSpec,  secretRef,  serviceAccountNames,  additionalProperties,  super.hashCode());
  }
  public class SecretRefNestedImpl<N> extends io.fabric8.kubernetes.api.model.ObjectReferenceFluentImpl<io.fabric8.openshift.api.model.miscellaneous.cloudcredential.v1.CredentialsRequestSpecFluent.SecretRefNested<N>> implements io.fabric8.openshift.api.model.miscellaneous.cloudcredential.v1.CredentialsRequestSpecFluent.SecretRefNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    SecretRefNestedImpl(io.fabric8.kubernetes.api.model.ObjectReference item) {
      this.builder = new io.fabric8.kubernetes.api.model.ObjectReferenceBuilder(this, item);
    }
    SecretRefNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.ObjectReferenceBuilder(this);
    }
    io.fabric8.kubernetes.api.model.ObjectReferenceBuilder builder;
    public N and() {
      return (N) CredentialsRequestSpecFluentImpl.this.withSecretRef(builder.build());
    }
    public N endSecretRef() {
      return and();
    }
    
  }
  
}

==> openshift-model-miscellaneous-5.12.2-sources.jar: io/fabric8/openshift/api/model/miscellaneous/cloudcredential/v1/CredentialsRequestSpecFluentImpl.java <==
package io.fabric8.openshift.api.model.miscellaneous.cloudcredential.v1;

import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import io.fabric8.kubernetes.api.model.ObjectReferenceFluentImpl;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import io.fabric8.kubernetes.api.model.ObjectReference;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.model.ObjectReferenceBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class CredentialsRequestSpecFluentImpl<A extends io.fabric8.openshift.api.model.miscellaneous.cloudcredential.v1.CredentialsRequestSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.miscellaneous.cloudcredential.v1.CredentialsRequestSpecFluent<A>{
  public CredentialsRequestSpecFluentImpl() {
  }
  public CredentialsRequestSpecFluentImpl(io.fabric8.openshift.api.model.miscellaneous.cloudcredential.v1.CredentialsRequestSpec instance) {
    this.withProviderSpec(instance.getProviderSpec()); 
    this.withSecretRef(instance.getSecretRef()); 
    this.withServiceAccountNames(instance.getServiceAccountNames()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.util.Map<java.lang.String,java.lang.Object> providerSpec;
  private io.fabric8.kubernetes.api.model.ObjectReferenceBuilder secretRef;
  private java.util.List<java.lang.String> serviceAccountNames = new java.util.ArrayList<java.lang.String>();
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public A addToProviderSpec(java.lang.String key,java.lang.Object value) {
    if(this.providerSpec == null && key != null && value != null) { this.providerSpec = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.providerSpec.put(key, value);} return (A)this;
  }
  public A addToProviderSpec(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.providerSpec == null && map != null) { this.providerSpec = new java.util.LinkedHashMap(); }
    if(map != null) { this.providerSpec.putAll(map);} return (A)this;
  }
  public A removeFromProviderSpec(java.lang.String key) {
    if(this.providerSpec == null) { return (A) this; }
    if(key != null && this.providerSpec != null) {this.providerSpec.remove(key);} return (A)this;
  }
  public A removeFromProviderSpec(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.providerSpec == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.providerSpec != null){this.providerSpec.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getProviderSpec() {
    return this.providerSpec;
  }
  public <K,V>A withProviderSpec(java.util.Map<java.lang.String,java.lang.Object> providerSpec) {
    if (providerSpec == null) { this.providerSpec =  null;} else {this.providerSpec = new java.util.LinkedHashMap(providerSpec);} return (A) this;
  }
  public java.lang.Boolean hasProviderSpec() {
    return this.providerSpec != null;
  }
  
  /**
   * This method has been deprecated, please use method buildSecretRef instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.ObjectReference getSecretRef() {
    return this.secretRef!=null?this.secretRef.build():null;
  }
  public io.fabric8.kubernetes.api.model.ObjectReference buildSecretRef() {
    return this.secretRef!=null?this.secretRef.build():null;
  }
  public A withSecretRef(io.fabric8.kubernetes.api.model.ObjectReference secretRef) {
    _visitables.get("secretRef").remove(this.secretRef);
    if (secretRef!=null){ this.secretRef= new io.fabric8.kubernetes.api.model.ObjectReferenceBuilder(secretRef); _visitables.get("secretRef").add(this.secretRef);} return (A) this;
  }
  public java.lang.Boolean hasSecretRef() {
    return this.secretRef != null;
  }
  public io.fabric8.openshift.api.model.miscellaneous.cloudcredential.v1.CredentialsRequestSpecFluent.SecretRefNested<A> withNewSecretRef() {
    return new io.fabric8.openshift.api.model.miscellaneous.cloudcredential.v1.CredentialsRequestSpecFluentImpl.SecretRefNestedImpl();
  }
  public io.fabric8.openshift.api.model.miscellaneous.cloudcredential.v1.CredentialsRequestSpecFluent.SecretRefNested<A> withNewSecretRefLike(io.fabric8.kubernetes.api.model.ObjectReference item) {
    return new io.fabric8.openshift.api.model.miscellaneous.cloudcredential.v1.CredentialsRequestSpecFluentImpl.SecretRefNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.miscellaneous.cloudcredential.v1.CredentialsRequestSpecFluent.SecretRefNested<A> editSecretRef() {
    return withNewSecretRefLike(getSecretRef());
  }
  public io.fabric8.openshift.api.model.miscellaneous.cloudcredential.v1.CredentialsRequestSpecFluent.SecretRefNested<A> editOrNewSecretRef() {
    return withNewSecretRefLike(getSecretRef() != null ? getSecretRef(): new io.fabric8.kubernetes.api.model.ObjectReferenceBuilder().build());
  }
  public io.fabric8.openshift.api.model.miscellaneous.cloudcredential.v1.CredentialsRequestSpecFluent.SecretRefNested<A> editOrNewSecretRefLike(io.fabric8.kubernetes.api.model.ObjectReference item) {
    return withNewSecretRefLike(getSecretRef() != null ? getSecretRef(): item);
  }
  public A addToServiceAccountNames(java.lang.Integer index,java.lang.String item) {
    if (this.serviceAccountNames == null) {this.serviceAccountNames = new java.util.ArrayList<java.lang.String>();}
    this.serviceAccountNames.add(index, item);
    return (A)this;
  }
  public A setToServiceAccountNames(java.lang.Integer index,java.lang.String item) {
    if (this.serviceAccountNames == null) {this.serviceAccountNames = new java.util.ArrayList<java.lang.String>();}
    this.serviceAccountNames.set(index, item); return (A)this;
  }
  public A addToServiceAccountNames(java.lang.String... items) {
    if (this.serviceAccountNames == null) {this.serviceAccountNames = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.serviceAccountNames.add(item);} return (A)this;
  }
  public A addAllToServiceAccountNames(java.util.Collection<java.lang.String> items) {
    if (this.serviceAccountNames == null) {this.serviceAccountNames = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.serviceAccountNames.add(item);} return (A)this;
  }
  public A removeFromServiceAccountNames(java.lang.String... items) {
    for (java.lang.String item : items) {if (this.serviceAccountNames!= null){ this.serviceAccountNames.remove(item);}} return (A)this;
  }
  public A removeAllFromServiceAccountNames(java.util.Collection<java.lang.String> items) {
    for (java.lang.String item : items) {if (this.serviceAccountNames!= null){ this.serviceAccountNames.remove(item);}} return (A)this;
  }
  public java.util.List<java.lang.String> getServiceAccountNames() {
    return this.serviceAccountNames;
  }
  public java.lang.String getServiceAccountName(java.lang.Integer index) {
    return this.serviceAccountNames.get(index);
  }
  public java.lang.String getFirstServiceAccountName() {
    return this.serviceAccountNames.get(0);
  }
  public java.lang.String getLastServiceAccountName() {
    return this.serviceAccountNames.get(serviceAccountNames.size() - 1);
  }
  public java.lang.String getMatchingServiceAccountName(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: serviceAccountNames) { if(predicate.test(item)){ return item;} } return null;
  }
  public java.lang.Boolean hasMatchingServiceAccountName(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: serviceAccountNames) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withServiceAccountNames(java.util.List<java.lang.String> serviceAccountNames) {
    if (serviceAccountNames != null) {this.serviceAccountNames = new java.util.ArrayList(); for (java.lang.String item : serviceAccountNames){this.addToServiceAccountNames(item);}} else { this.serviceAccountNames = null;} return (A) this;
  }
  public A withServiceAccountNames(java.lang.String... serviceAccountNames) {
    if (this.serviceAccountNames != null) {this.serviceAccountNames.clear();}
    if (serviceAccountNames != null) {for (java.lang.String item :serviceAccountNames){ this.addToServiceAccountNames(item);}} return (A) this;
  }
  public java.lang.Boolean hasServiceAccountNames() {
    return serviceAccountNames != null && !serviceAccountNames.isEmpty();
  }
  public A addNewServiceAccountName(java.lang.String arg0) {
    return (A)addToServiceAccountNames(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    CredentialsRequestSpecFluentImpl that = (CredentialsRequestSpecFluentImpl) o;
    if (providerSpec != null ? !providerSpec.equals(that.providerSpec) :that.providerSpec != null) return false;
    if (secretRef != null ? !secretRef.equals(that.secretRef) :that.secretRef != null) return false;
    if (serviceAccountNames != null ? !serviceAccountNames.equals(that.serviceAccountNames) :that.serviceAccountNames != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(providerSpec,  secretRef,  serviceAccountNames,  additionalProperties,  super.hashCode());
  }
  public class SecretRefNestedImpl<N> extends io.fabric8.kubernetes.api.model.ObjectReferenceFluentImpl<io.fabric8.openshift.api.model.miscellaneous.cloudcredential.v1.CredentialsRequestSpecFluent.SecretRefNested<N>> implements io.fabric8.openshift.api.model.miscellaneous.cloudcredential.v1.CredentialsRequestSpecFluent.SecretRefNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    SecretRefNestedImpl(io.fabric8.kubernetes.api.model.ObjectReference item) {
      this.builder = new io.fabric8.kubernetes.api.model.ObjectReferenceBuilder(this, item);
    }
    SecretRefNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.ObjectReferenceBuilder(this);
    }
    io.fabric8.kubernetes.api.model.ObjectReferenceBuilder builder;
    public N and() {
      return (N) CredentialsRequestSpecFluentImpl.this.withSecretRef(builder.build());
    }
    public N endSecretRef() {
      return and();
    }
    
  }
  
}
